==> log4cxx_0.12.1.orig.tar.gz: apache-log4cxx-0.12.1/src/site/markdown/community/mailing-lists.md <==
Mailing Lists {#mailing-lists}
===
<!--
 Note: License header cannot be first, as doxygen does not generate
 cleanly if it before the '==='
-->
<!--
 Licensed to the Apache Software Foundation (ASF) under one or more
 contributor license agreements.  See the NOTICE file distributed with
 this work for additional information regarding copyright ownership.
 The ASF licenses this file to You under the Apache License, Version 2.0
 (the "License"); you may not use this file except in compliance with
 the License.  You may obtain a copy of the License at

	http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
-->
These are the mailing lists that have been established for
this project. For each list, there is a subscribe, unsubscribe, and an
archive link.
|                                              |                                                               |                                                                   |                                                |                                                                                            |                                                                                 |
| -------------------------------------------- | ------------------------------------------------------------- | ----------------------------------------------------------------- | ---------------------------------------------- | ------------------------------------------------------------------------------------------ | ------------------------------------------------------------------------------- |
| Name                                         | Subscribe                                                     | Unsubscribe                                                       | Post                                           | Archive                                                                                    | Other Archives                                                                  |
| log4cxx usage                                | [Subscribe](mailto:log4cxx-user-subscribe@logging.apache.org) | [Unsubscribe](mailto:log4cxx-user-unsubscribe@logging.apache.org) | [Post](mailto:log4cxx-user@logging.apache.org) | [mail-archives.apache.org](http://mail-archives.apache.org/mod_mbox/logging-log4cxx-user/) | [markmail.org](http://markmail.org/search/list:org.apache.logging.log4cxx-user) |
| \-                                           | \-                                                            | \-                                                                | \-                                             | \-                                                                                         | [marc.info](http://marc.info/?l=log4cxx-user)                                   |
| \-                                           | \-                                                            | \-                                                                | \-                                             | \-                                                                                         | [dir.gmane.org](http://dir.gmane.org/gmane.comp.apache.logging.log4cxx.user)    |
| log4cxx development                          | [Subscribe](mailto:dev-subscribe@logging.apache.org)          | [Unsubscribe](mailto:dev-unsubscribe@logging.apache.org)          | [Post](mailto:dev@logging.apache.org)          | [mail-archives.apache.org](http://mail-archives.apache.org/mod_mbox/logging-dev/)          | [markmail.org](http://markmail.org/search/list:org.apache.logging.dev)          |
| \-                                           | \-                                                            | \-                                                                | \-                                             | \-                                                                                         | [marc.info](http://marc.info/?l=dev)                                            |
| \-                                           | \-                                                            | \-                                                                | \-                                             | \-                                                                                         | [dir.gmane.org](http://dir.gmane.org/gmane.comp.apache.logging.devel)           |
| Old log4cxx development (NOT USED ANYMORE\!) | [Subscribe](mailto:log4cxx-dev-subscribe@logging.apache.org)  | [Unsubscribe](mailto:log4cxx-dev-unsubscribe@logging.apache.org)  | [Post](mailto:log4cxx-dev@logging.apache.org)  | [mail-archives.apache.org](http://mail-archives.apache.org/mod_mbox/logging-log4cxx-dev/)  | [markmail.org](http://markmail.org/search/list:org.apache.logging.log4cxx-dev)  |
| \-                                           | \-                                                            | \-                                                                | \-                                             | \-                                                                                         | [marc.info](http://marc.info/?l=log4cxx-dev)                                    |
| \-                                           | \-                                                            | \-                                                                | \-                                             | \-                                                                                         | [dir.gmane.org](http://dir.gmane.org/gmane.comp.apache.logging.log4cxx.devel)   |

==> log4cxx_1.1.0.orig.tar.gz: apache-log4cxx-1.1.0/src/site/markdown/community/mailing-lists.md <==
Mailing Lists {#mailing-lists}
===
<!--
 Note: License header cannot be first, as doxygen does not generate
 cleanly if it before the '==='
-->
<!--
 Licensed to the Apache Software Foundation (ASF) under one or more
 contributor license agreements.  See the NOTICE file distributed with
 this work for additional information regarding copyright ownership.
 The ASF licenses this file to You under the Apache License, Version 2.0
 (the "License"); you may not use this file except in compliance with
 the License.  You may obtain a copy of the License at

	http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
-->
These are the mailing lists that have been established for
this project. For each list, there is a subscribe, unsubscribe, and an
archive link.
|                                              |                                                               |                                                                   |                                                |                                                                                            |                                                                                 |
| -------------------------------------------- | ------------------------------------------------------------- | ----------------------------------------------------------------- | ---------------------------------------------- | ------------------------------------------------------------------------------------------ | ------------------------------------------------------------------------------- |
| Name                                         | Subscribe                                                     | Unsubscribe                                                       | Post                                           | Archive                                                                                    | Other Archives                                                                  |
| Log4cxx usage                                | [Subscribe](mailto:log4cxx-user-subscribe@logging.apache.org) | [Unsubscribe](mailto:log4cxx-user-unsubscribe@logging.apache.org) | [Post](mailto:log4cxx-user@logging.apache.org) | [mail-archives.apache.org](http://mail-archives.apache.org/mod_mbox/logging-log4cxx-user/) | [markmail.org](http://markmail.org/search/list:org.apache.logging.log4cxx-user) |
| \-                                           | \-                                                            | \-                                                                | \-                                             | \-                                                                                         | [marc.info](http://marc.info/?l=log4cxx-user)                                   |
| \-                                           | \-                                                            | \-                                                                | \-                                             | \-                                                                                         | [dir.gmane.org](http://dir.gmane.org/gmane.comp.apache.logging.log4cxx.user)    |
| Log4cxx development                          | [Subscribe](mailto:dev-subscribe@logging.apache.org)          | [Unsubscribe](mailto:dev-unsubscribe@logging.apache.org)          | [Post](mailto:dev@logging.apache.org)          | [mail-archives.apache.org](http://mail-archives.apache.org/mod_mbox/logging-dev/)          | [markmail.org](http://markmail.org/search/list:org.apache.logging.dev)          |
| \-                                           | \-                                                            | \-                                                                | \-                                             | \-                                                                                         | [marc.info](http://marc.info/?l=dev)                                            |
| \-                                           | \-                                                            | \-                                                                | \-                                             | \-                                                                                         | [dir.gmane.org](http://dir.gmane.org/gmane.comp.apache.logging.devel)           |
| Old Log4cxx development (NOT USED ANYMORE\!) | [Subscribe](mailto:log4cxx-dev-subscribe@logging.apache.org)  | [Unsubscribe](mailto:log4cxx-dev-unsubscribe@logging.apache.org)  | [Post](mailto:log4cxx-dev@logging.apache.org)  | [mail-archives.apache.org](http://mail-archives.apache.org/mod_mbox/logging-log4cxx-dev/)  | [markmail.org](http://markmail.org/search/list:org.apache.logging.log4cxx-dev)  |
| \-                                           | \-                                                            | \-                                                                | \-                                             | \-                                                                                         | [marc.info](http://marc.info/?l=log4cxx-dev)                                    |
| \-                                           | \-                                                            | \-                                                                | \-                                             | \-                                                                                         | [dir.gmane.org](http://dir.gmane.org/gmane.comp.apache.logging.log4cxx.devel)   |
